# 20221027_v0.9.9_crab_tuned

DL1ab step to apply NSB tuning for Crab.

Generated config:

``` 
lstmcpipe_generate_config PathConfigAllSkyFullDL1ab --dec_list dec_2276 --prod_id 20221027_v0.9.9_crab_tuned --kwargs source_prod_id=20221021_crab_full_lstchain097
```

lstchain config taken from `20221021_crab_full_lstchain097`


Contact:Thomas or Abelardo


